#region  == Copyright ==
// =====================================================================
//  Microsoft Consulting Services France - Aymeric Mouill - 2013
//  Projet     : TFS WorkItemTracker - TFS WorkItemTracker
//  Fichier    : StatControl.cs (01/05/2013 18:40)
//  
//  Copyright (C) Microsoft Corporation.  All rights reserved.
// =====================================================================
#endregion

namespace TFS.WorkItemTracker
{
    #region  == Using ==
    using System;
    using System.Collections.Generic;
    using System.Windows.Forms;

    using Microsoft.TeamFoundation.WorkItemTracking.Client;

    using TFS.WorkItemTracker.Properties;

    #endregion

    public partial class StatControl : UserControl
    {
        private float TotalCompletedWork;

        private float TotalOriginalEstimate;

        private List<WorkItemLine> WorkItemLines;

        private WorkItemStore WorkItemStore;

        private MainForm MainForm;

        #region = Constructor =
        /// <summary>
        /// Initializes a new instance of the <see cref="StatControl" /> class.
        /// </summary>
        public StatControl()
        {
            InitializeComponent();
        }
        #endregion

        #region Stat Control Load
        /// <summary>
        /// Handles the Load event of the StatControl control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">
        /// The <see cref="EventArgs" /> instance containing the event data.
        /// </param>
        private void StatControl_Load(object sender, EventArgs e)
        {
            BindData();
        }
        #endregion

        #region Load Data
        /// <summary>
        /// Loads the data.
        /// </summary>
        private void LoadData()
        {
            WorkItemLines = new List<WorkItemLine>();

            TotalOriginalEstimate = 0;
            TotalCompletedWork = 0;

            string wiqlQuery = string.Empty;
            wiqlQuery += "SELECT ID, Title ";
            wiqlQuery += "FROM workitems ";
            wiqlQuery += "WHERE [Closed Date] =  '" + dateTimePicker.Value.ToShortDateString() + "' ";
            wiqlQuery += string.Format("AND [System.AssignedTo] = '{0}' ", WorkItemStore.TeamFoundationServer.AuthenticatedUserDisplayName);
            wiqlQuery += "AND State = 'Closed' ";
            wiqlQuery += "ORDER by [Closed Date]";

            WorkItemCollection witCollection = WorkItemStore.Query(wiqlQuery);
            foreach (WorkItem workItem in witCollection)
            {
                WorkItemLine workItemLine = Utils.ConvertWorkItemToLine(workItem);

                TotalOriginalEstimate += workItemLine.OriginalEstimate;
                TotalCompletedWork += workItemLine.CompletedWork;

                WorkItemLines.Add(workItemLine);
            }

            txtOriginalEstimate.Text = Utils.ConvertHourValueToHourTimeDisplay(TotalOriginalEstimate);
            txtTotalCompletedWork.Text = Utils.ConvertHourValueToHourTimeDisplay(TotalCompletedWork);

            if (MainForm != null)
            {
                MainForm.SetStatus(string.Format("Query results : {0} WorkItem(s) found", witCollection.Count));
            }
        }
        #endregion

        #region Bind Data
        /// <summary>
        /// Binds the data.
        /// </summary>
        private void BindData()
        {
            if (string.IsNullOrEmpty(Settings.Default.TFSProjectCollectionUrl))
            {
                return;
            }
            try
            {
                if (ParentForm != null
                    && ParentForm is MainForm)
                {
                    MainForm = (MainForm)ParentForm;
                }
                WorkItemStore = new WorkItemStore(Settings.Default.TFSProjectCollectionUrl);

                gdvWorkItems.DataSource = null;
                LoadData();
                gdvWorkItems.DataSource = WorkItemLines;
            }
            catch (Exception ex)
            {
                if (MessageBox.Show(ex.ToString(), "An error occured", MessageBoxButtons.RetryCancel, MessageBoxIcon.Stop) == DialogResult.Retry)
                {
                    BindData();
                }
            }
        }
        #endregion

        #region Stat Control Enter
        /// <summary>
        /// Handles the Enter event of the StatControl control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">
        /// The <see cref="EventArgs" /> instance containing the event data.
        /// </param>
        private void StatControl_Enter(object sender, EventArgs e)
        {
            BindData();
        }
        #endregion

        #region Date Time Picker Value Changed
        /// <summary>
        /// Handles the ValueChanged event of the dateTimePicker control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">
        /// The <see cref="EventArgs" /> instance containing the event data.
        /// </param>
        private void dateTimePicker_ValueChanged(object sender, EventArgs e)
        {
            BindData();
        }
        #endregion

        #region Stat Control Visible Changed
        /// <summary>
        /// Handles the VisibleChanged event of the StatControl control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">
        /// The <see cref="EventArgs" /> instance containing the event data.
        /// </param>
        private void StatControl_VisibleChanged(object sender, EventArgs e)
        {
            BindData();
        }
        #endregion
    }
}
