#region  == Copyright == 
// =====================================================================
//  Microsoft Consulting Services France - Aymeric Mouill - 2013
//  Projet     : TFS WorkItemTracker - TFS WorkItemTracker
//  Fichier    : Utils.cs (01/05/2013 18:40)
//  
//  Copyright (C) Microsoft Corporation.  All rights reserved.
// =====================================================================
#endregion

namespace TFS.WorkItemTracker
{
    #region  == Using == 
    using System;

    using Microsoft.TeamFoundation.WorkItemTracking.Client;

    #endregion

    public static class Utils
    {
        #region Get Field Value
        /// <summary>
        /// Gets the field value.
        /// </summary>
        /// <param name="workItem">The work item.</param>
        /// <param name="fieldName">Name of the field.</param>
        /// <returns></returns>
        public static string GetFieldValue(WorkItem workItem, String fieldName)
        {
            if (workItem.Fields.Contains(fieldName))
            {
                if (workItem.Fields[fieldName] != null)
                {
                    if (workItem.Fields[fieldName].Value != null)
                    {
                        return workItem.Fields[fieldName].Value.ToString();
                    }
                }
            }
            return "0";
        }
        #endregion

        #region Convert Work Item To Line
        /// <summary>
        /// Converts the work item to line.
        /// </summary>
        /// <param name="workItem">The work item.</param>
        /// <returns></returns>
        public static WorkItemLine ConvertWorkItemToLine(WorkItem workItem)
        {
            WorkItemLine workItemLine = new WorkItemLine
                                            {
                                                Id = workItem.Id, 
                                                Title = workItem.Title, 
                                                Area = workItem.AreaPath, 
                                                Iteration = workItem.IterationPath, 
                                                Created = workItem.CreatedDate, 
                                                Changed = workItem.ChangedDate, 
                                                OriginalEstimate = float.Parse(GetFieldValue(workItem, "Original Estimate")), 
                                                CompletedWork = float.Parse(GetFieldValue(workItem, "Completed Work")), 
                                                RemainingWork = float.Parse(GetFieldValue(workItem, "Remaining Work"))
                                            };

            if (workItem.ExternalLinkCount > 0)
            {
                foreach (var link in workItem.Links)
                {
                    if (link is ExternalLink)
                    {
                        var changeSet = ((ExternalLink)link).LinkedArtifactUri.Replace("vstfs:///VersionControl/Changeset/", String.Empty);
                        if (!String.IsNullOrEmpty(workItemLine.AssociatedChangeSets))
                        {
                            workItemLine.AssociatedChangeSets += "; ";
                        }
                        workItemLine.AssociatedChangeSets += changeSet;
                    }
                }
            }

            return workItemLine;
        }
        #endregion

        #region Convert Hour Value To Hour Time Display
        /// <summary>
        /// Converts the hour value to hour time display.
        /// </summary>
        /// <param name="hourValue">The hour value.</param>
        /// <returns></returns>
        public static String ConvertHourValueToHourTimeDisplay(float hourValue)
        {
            int hourSeconds = (int)(hourValue * 3600);
            TimeSpan time = new TimeSpan(0, 0, hourSeconds);
            return time.ToString();
        }
        #endregion
    }
}
